<?php
/**
* This file sets all the configuration options
* All configuration options, such as colors,
*  text sizes, email addresses, etc.
*  are set in this file.
* @author Nick Korbel <lqqkout13@users.sourceforge.net>
* @version 12-14-03
* @package phpScheduleIt
*/
/***************************************
* phpScheduleIt                        *
* Version 0.9.3                        *
* http://phpscheduleit.sourceforge.net *
*                                      *
* Nick Korbel                          *
* lqqkout13@users.sourceforge.net      *
/***************************************/
/**
* Please refer to readme.html and LICENSE for any additional information
*
* Copyright (C) 2004 phpScheduleIt 
* This program is free software; you can redistribute it and/or modify it
* under the terms of the GNU General Public License as published by the 
* Free Software Foundation; either version 2 of the License, or (at your option) 
* any later version.
*
* This program is distributed in the hope that it will be useful, but WITHOUT 
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License along with 
* this program; if not, write to the 
* Free Software Foundation, Inc.
* 59 Temple Place
* Suite 330
* Boston, MA
* 02111-1307
* USA
*/

/////////////////////////////
// Define common variables //
/////////////////////////////

/*************************************************/
/*                Instructions                   *
**************************************************
* + This section will allow you to change        *
*  common settings such as the time of           *
*  the start and end of the workday              *
*                                                *
* + All times MUST be specified in               *
*  24 hour clock                                 *
*  with half hours denoted as x.5                *
*  (ie: 4:30 pm = 16.5)                          *
*  ONLY full and half hours are accepted         *
*                                                *
* + All words (string values) must               *
*  be enclosed in quotation marks                *
*  Numbers must not                              *
*                                                *
* + Default values are                           *
*  given in square brackets []                   *
/*************************************************/

// The full url to the root directory of phpScheduleIt
// Please do not include the trailing slash
$conf['app']['weburi'] = 'http://www.yourwebsite.com/path_to_phpScheduleIt';

// Login email for the administrator [your@email.com]
// It will be used to allow special admin features
// And as the contact email address for users with questions
$conf['app']['adminEmail'] = 'admin@email.com';

// Start time of resource availability (in 24 hour time) [8.0]
// Define half hours with 0x.5
$conf['app']['startDay'] = 8.0;     

// End time of resource availability (in 24 hour time) [20.0]
// Define half hours with 0x.5
$conf['app']['endDay'] = 20.0;

// Time multiple for reservations [30]
// This is the minimum time a reservation can last
$conf['app']['timeSpan'] = 30;

// View time in 12 or 24 hour format [12]
// Only acceptable values are 12 and 24 (if an invalid number is set, 12 hour time will be used)
$conf['app']['timeFormat'] = 12;

// Number of days to view on the scheduler [7]
$conf['app']['viewDays'] = 7;

// Starting day of the week [0]
// 0 => Sunday, 6=> Saturday
$conf['app']['weekStartDay'] = 0;

// Email address of technical support [your@email.com]
$conf['app']['techEmail'] = '';

// Email addresses of additional people to email []
// Multiple addresses must be seperated by a comma
$conf['app']['ccEmail'] = '';

// Whether to send email notifications of reservation and registration activity to administrator [1]
// can be 0 (for no) or 1 (for yes)
$conf['app']['emailAdmin'] = 1;

// Title of application ['phpScheduleIt']
// Will be used for page titles and in 'From' field of email responses
$conf['app']['title'] = 'phpScheduleIt';

// If we should use the permission system or not [1]
// Without permissions, everyone can use any resource
// Can be 0 (for no) or 1 (for yes)
$conf['app']['use_perms'] = 1;

// If the user should be automatically given permission on all resources [0]
// Please note that this is not recommended
// Can be 0 (for no) or 1 (for yes)
$conf['app']['auto_assign'] = 0;

// If we should log system activity or not [1]
// Can be 0 (for no) and 1 (for yes)
$conf['app']['use_log'] = 0;

// Directory/file for log ['/var/log/phpscheduleitlog.txt']
// Specify as /directory/filename.extension
$conf['app']['logfile'] = '/var/log/phpscheduleitlog.txt';

// Database type to be used by PEAR
/* Options are:
	mysql  -> MySQL
	pgsql  -> PostgreSQL
	ibase  -> InterBase
	msql   -> Mini SQL
	mssql  -> Microsoft SQL Server
	oci8   -> Oracle 7/8/8i
	odbc   -> ODBC (Open Database Connectivity)
	sybase -> SyBase
	ifx    -> Informix
	fbsql  -> FrontBase
*/
$conf['db']['dbType'] = 'mysql';

// Database user who can access the schedule database [schedule_user]
$conf['db']['dbUser'] = 'schedule_user';

// Password for above user to access schedule database
$conf['db']['dbPass'] = 'password';

// Name for database
$conf['db']['dbName'] = 'phpScheduleIt';

// If we should drop (or overwrite) an existing database with the same name during installation
// Can be 0 (for no) or 1 (for yes)
$conf['db']['drop_old'] = 0;

// Prefix to attach to all program-generated primary keys
// This will be used to create unique primary keys when multiple databases are being used
// * 3 characterss or less.  Anything over 3 chars will be cut down
$conf['db']['pk_prefix'] = 'sc1';

// Announcement messages to be displayed on My Control Panel
// Comment out (add // before all $conf['ui']['announcement'][]) to display no messages
// Add $conf['ui']['announcement'] values to add more messages
// Last announcement will be displayed first
$conf['ui']['announcement'] = array();			// DO NOT CHANGE THIS LINE
//$conf['ui']['announcement'][] = "";

// Image to appear at the top of each page ['img/phpScheduleIt.gif']
// Leave this string empty if you are not going to use an image
// Specifiy link as 'directory/filename.gif'
$conf['ui']['logoImage'] = 'img/phpScheduleIt.gif';

// Welcome message show at login page ['Welcome to phpScheduleIt!']
$conf['ui']['welcome'] = 'Welcome to phpScheduleIt!';

/*
Configure this section to customize the color of reserved time blocks
Set 'color' to be the color when the mouse is not over the reseravtion
Set 'hover' to be the color when the mouse is moved over the reservation
Please DO NOT put the hash mark (#) before the colors

'my_res' is the colors that will be used for all the upcoming reservations that the current user owns
'other_res' is the colors that will be used for all the upcoming reservations on the schedule that the current user does not own
'my_past_res' is the colors that will be used for all past reservations that the current user owns
'other_past_res' is the colors that will be used for all past reservations that the current user does not own
*/
$conf['ui']['my_res'][]         = array ('color' => '5E7FB1', 'hover' => '799DD3');
$conf['ui']['other_res'][]      = array ('color' => 'D2DDEC', 'hover' => 'AFBED3');
$conf['ui']['my_past_res'][]    = array ('color' => 'A0A1A1', 'hover' => '6F7070');
$conf['ui']['other_past_res'][] = array ('color' => 'CFCFCF', 'hover' => 'ABABAB');

// Available positions to select when registering
// If you add values to this variable, they will appear in a pull down menu.  If you do not add values
//  then the position field will be a text box instead of a pull down menu
// Comment out (add // before all $conf['ui']['positions'][]) to display a text box instead of a select menu
// Add $conf['ui']['positions'][] values to add positions
$conf['ui']['positions'] = array();			// DO NOT CHANGE THIS LINE
//$conf['ui']['positions'][] = "";

// Available institutions to select when registering
// If you add values to this variable, they will appear in a pull down menu.  If you do not add values
//  then the institution field will be a text box instead of a pull down menu
// Comment out (add // before all $conf['ui']['institutions'][]) to display a text box instead of a select menu
// Add $conf['ui']['institutions'][] values to add institutions
$conf['ui']['institutions'] = array();			// DO NOT CHANGE THIS LINE
//$conf['ui']['institutions'][] = "";
							
//////////////////////////
// End common variables //
//////////////////////////


/********************************************************************/
/*                   DO NOT CHANGE THIS SECTION                     */
/********************************************************************/
// Start the session (do not edit!)
session_start();

// Turn off magic quotes (do not edit!)
set_magic_quotes_runtime(0);

$conf['app']['version'] = '0.9.3';

$conf['app']['startDay'] *= 60;			// Make these into minutes
$conf['app']['endDay'] *= 60;
/********************************************************************/
?>