<?php
/**
* Calendar navigator window
*
* This is a calendar applicaion that simply
* provides a visual way for users to choose
* a day to jump to on the scheduler app
* It prints out a XHTML 1.1 standard calendar
*
* The calendar should be opened using a javascript
* window.open() function.  The recommended syntax would be:
* window.open('calendar_opening_file.php','calendar','width=###,height=###,scrollbars=no,location=no,menubar=no,toolbar=no,resizable=yes');
* subbing actual calendar opener filename and width/height size
* Note: void(0); is needed after the window.open() function if used in a link
* Ex) <a href="javascript: window.open('cal_test.php','calendar','width=280,height=280,scrollbars=no,location=no,menubar=no,toolbar=no'); void(0);">Link to open calendar</a>
*
* Extend the class and override any functions to add/change functionality
*
* @author Nick Korbel <lqqkout13@users.sourceforge.net>
* @version 11-08-03
* @package Calendar
*/
class Calendar {
    /**
    * Calendar::$borderColor
    *
    * Calendar border color
    */
    var $borderColor = '#000000';

    /**
    * Calendar::$ed_bgcolor
    *
    * Empty day cell background color
    */
    var $ed_bgcolor = '#F0F0F0';

    /**
    * Calendar::$fd_bgcolor
    *
    * Full day cell background color
    */
    var $fd_bgcolor = '#FFFFFF';

	/**
	* Calendar::$hilite_color
	*
	* Hilighted day background color
	*/
	var $hilite_color = '#FFFACD';
    
	/**
    * Calendar::$boxSize
    *
    * Box size (in pixels)
    */
    var $boxSize = '20px';

    /**
    * Calendar::$dn_bgcolor
    *
    * Day name cell background color
    */
    var $dn_bgcolor = '#999999';

    /**
    * Calendar::$dn_textcolor
    *
    * Day name font color
    */
    var $dn_textcolor = '#FFFFFF';

    /**
    * Calendar::$linkColor
    *
    * Day link color
    */
    var $linkColor = '#000000';

    /**
    * Calendar::$linkHover
    *
    * Day link hover color
    */
    var $linkHover = '#000000';

    /**
    * Calendar::$monthColor
    *
    * Month link color
    */
    var $monthColor = '#000000';

    /**
    * Calendar::$monthHover
    *
    * Month link hover color
    */
    var $monthHover = '#000000';

    /**
    * Calendar::$select_bgcolor
    *
    * Select menu background color
    */
    var $select_bgcolor = '#F0F0F0';

    /**
    * Calendar::$selectSize
    *
    * Select menu font size
    */
    var $selectSize = '11px';

    /**
    * Calendar::$select_textcolor
    *
    * Select menu font color
    */
    var $select_textcolor = '#000000';

    /**
    * Calendar::$textSize
    *
    * Common text size
    */
    var $textSize = '10px';

    /**
    * Calendar::$titleSize
    *
    * Font size of title (in pixels)
    */
    var $titleSize = '13px';

    /**
    * Create a new Calendar object with default values
    *
    * This will create a new Calendar using default
    * colors, font sizes, and other attributes
    * @param none
    */
    function Calendar() {
    }


    /**
    * Prints out header data to configure calendar
    *
    * This function prints out HTML head code including
    * CSS and JavaScript functions
    *
    * Should be overridden with an empty function if Calendar
    * is going to be embedded within a page
    *
    * @param string $month optional parameter for printing month name
    * @param int $year optional parameter for printing year
    * @see printCSS()
    * @see printJS()
    */
    function printHTMLHead($month='', $year='') {
        echo "<?xml version=\"1.0\" encoding=\"iso-8859-1\"?>\n";
        ?>
        <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
            "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
        <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
          <head>
            <title><?= $month . " " . $year ?></title>
        <?
        // Print Cascading Style Sheet and JavaScript functions
        $this->printCSS();
        $this->printJS();
        ?>
          </head>
          <body>
        <?
    }

    /**
    * Prints out Cascading Style Sheet
    *
    * Prints out the Cascading Style Sheet
    * code for the calendar to properly display
    *
    * This function should be overridden to add or change style sheet
    * @param none
    */
    function printCSS() {
    ?>
        <style type="text/css">
        <!--
        td.borderColor {
			background-color: <?= $this->borderColor ?>;
		}
        td.emptyDay {
			background-color: <?= $this->ed_bgcolor ?>;
		}
        td.fullDay {
			background-color: <?= $this->fd_bgcolor ?>;
		}
		td.highlighted {
			background-color: <?= $this->hilite_color ?>;
			font-weight: bold;
		}
        td.emptyDay, td.fullDay, td.highlighted, tr.dayNames {
			width: <?= $this->boxSize ?>;
			height: <?= $this->boxSize ?>;
			text-align: center;
			font-size: <?= $this->textSize ?>;
		}

        tr.dayNames {
			color: <?= $this->dn_textcolor ?>;
			background-color: <?= $this->dn_bgcolor ?>;
			font-weight: bold;
		}

        a.dayLink {
			color: <?= $this->linkColor ?>;
			text-decoration: none;
		}
        a.dayLink:hover {
			color: <?= $this->linkHover ?>;
			text-decoration: underline;
		}

        a.monthLink {
			color: <?= $this->monthColor ?>;
			text-decoration: none;
			font-size: 11px;
		}
        a.monthLink:hover {
			color: <?= $this->monthHover ?>;
			text-decoration: underline;
		}

        h5.calendarTitle {
			margin-top: 0px;
			font-size: <?= $this->titleSize ?>;
		}

        select.monthSelect {
			color: <?= $this->select_textcolor ?>;
			font-size: <?= $this->selectSize ?>;
			font-family: Arial, Helvetica, sans-serif;
			background-color: <?= $this->select_bgcolor ?>;
		}

        div.calendarBody {
			font-family: Arial, Helvetica, sans-serif;
			text-align: center;
		}
        div.calendarBody table {
			margin-left: auto;
			margin-right: auto;
		}
        -->
        </style>
    <?
    }
    
    
    /**
    * Print out JavaScript functions
    *
    * Prints out JavaScript to provide functionality for the Calendar
    * This function should be overriden to add or change functionality
    * @param none
    */
    function printJS() {
    ?>
        <script type="text/javascript">
        <!--
            // Function to respond to month link click
            function changeDate(month, year) {
        		document.forms[0].month.value = month;
        		document.forms[0].year.value = year;
        		document.forms[0].submit();
        	}
        	
        	// Function to change the Scheduler on selected date click
        	function changeScheduler(date) {
        	    // Get everything up to the "?" (if it even exists)
                var url = window.opener.document.URL.match(/[\w\/\:\.]+/);
        		window.opener.location = url + "?date=" + date;
        	}
        // -->
        </script>
    <?
    }


    /**
    * Print out HTML closing code
    *
    * This should be overridden with an empty function
    * if the Calendar is to be embedded within a page
    *
    * @param none
    */
    function printHTMLFoot() {
    ?>
      </body>
    </html>
    <?
    }

    /**
    * Print the actual calendar and jump functions
    *
    * This function prints out the calendar and calls all
    * the associated functions to print the calendar,
    * links and forms used to jump to a new month
    *
    * (This is the only function that needs to be called
    * after a Calendar has been created)
    * @param none
    * @see printHTMLHead()
    * @see printHTMLFoot()
    */
    function printCalendar() {
		$today = getdate();
        // Set up timestamp for passed in date or todays date
        $dateTS = (isset($_POST['month']) && isset($_POST['year'])) ? mktime(1,1,1,$_POST['month'],1,$_POST['year']) : mktime(1,1,1,$today['mon'],1,$today['year']);

        // Construct array for dateTS
        $dateArray = getDate($dateTS);

        // Month and Year int values
        $month = $dateArray['mon'];
        $year = $dateArray['year'];

        // Number value of the first day of the week of the month
        $firstWeekDay = date('w', $dateTS);
        // Number of days in this month
        $daysInMonth = date('t', $dateTS);
        // String name of this month
        $monthName = date('F', $dateTS);

        // Print out the HTML headers
        $this->printHTMLHead($monthName, $year);

        echo "<div class=\"calendarBody\">\n<h5 class=\"calendarTitle\">" . $monthName . ' ' . $year . "</h5>\n";
        ?>
        <table border="0" cellspacing="0" cellpadding="0">
          <tr>
            <td class="borderColor">
        	  <table border="0" cellspacing="1" cellpadding="3">
        		<tr class="dayNames">
        		  <td>S</td><td>M</td><td>T</td><td>W</td><td>T</td><td>F</td><td>S</td>
        		</tr>
        <?
            // Move to first day of the month
            echo "<tr>\n";
            for ($day = 0; $day < $firstWeekDay; $day++)
                echo "<td class=\"emptyDay\">&nbsp;</td>\n";

            // Initialize day
            $day = $firstWeekDay;
            // Initialize printRow
            $printRow = false;

            // Print out days for all weeks
            for ($currentDay = 0; $currentDay < $daysInMonth; /* No change needed */ ) {
                // See if we should start a new row
                // (will be for each time except first)
                if ($printRow) {
                    echo "<tr>\n";
                }
                $printRow = true;
                // Print out each day of this week
                for ( /* Day already set */ ; $day < 7; $day++) {
                    // If there are still more days to print, do it
                    if (++$currentDay <= $daysInMonth) {
						if ($currentDay == $today['mday'] && $month == $today['mon'] && $year == $today['year'])
							$class = 'highlighted';
						else
							$class = 'fullDay';
                        echo "<td class=\"$class\"><a href=\"javascript: changeScheduler('" . $month . "-" . $currentDay . "-" . $year . "');\" class=\"dayLink\">" . ($currentDay) . "</a></td>\n";
                    }
					else {
                        // Else print out empty cells
                        for ( /* Day already set */ ; $day < 7; $day++)
                            echo "<td class=\"emptyDay\">&nbsp;</td>\n";
                    }
                }

                // Reset day counter
                $day = 0;
                echo "</tr>\n";
            }
        ?>
        	  </table>
            </td>
          </tr>
        </table>
         <form id="changeMonth" action="<?= $_SERVER['PHP_SELF'] ?>" method="post">
            <table width="100%" border="0" cellspacing="0" cellpadding="3">
        	  <tr align="center">
        <?
        // Set values for prev/next month/year variables
        if ( ($month-1) <= 0) {
            $prevMonth = 12;
            $prevYear = $year-1;
        }
        else {
            $prevMonth = $month-1;
            $prevYear = $year;
        }

        if ( ($month+1) >= 13) {
            $nextMonth = 1;
            $nextYear = $year+1;
        }
        else {
            $nextMonth = $month+1;
            $nextYear = $year;
        }
        ?>
        		<td style="width: 33%"><a href="javascript: changeDate(<?= $prevMonth . "," . $prevYear?>);" class="monthLink"><?= "&lt; " . date("F",mktime(1,1,1,$prevMonth,1,$prevYear))  ?></a></td>
        		<td style="width: 33%">
        		  <select name="month" onchange="document.forms[0].submit();" class="monthSelect">
        <?
        for ($m = 1; $m < 13; $m++) {
            echo '<option value="' . $m . '"';
            if ($m == $month)
                echo ' selected="selected"';
            echo '>' . date('F',mktime(1,1,1,$m,1)) . "</option>\n";
        }
        ?>
        		  </select>
        		  <input type="hidden" name="year" value="<?= $year ?>" />
        		</td>
        		<td style="width: 33%"><a href="javascript: changeDate(<?= $nextMonth . "," . $nextYear?>);" class="monthLink"><?= date("F",mktime(1,1,1,$nextMonth,1,$nextYear)) . " &gt;" ?></a></td>
        	  </tr>
            </table>
          </form>
         </div>
    <?
    // Print HTML footer
    $this->printHTMLFoot();
    }


    /**
    * Sets the border color of the Calendar
    *
    * @param string $color HTML color
    */
    function setBorderColor($color) {
        $this->borderColor = $color;
    }

    /**
    * Sets the background color of the empty day cell of the Calendar
    *
    * @param string $color HTML color
    */
    function setEmptyDayBGColor($color) {
        $this->ed_bgcolor = $color;
    }

    /**
    * Sets the background color of the full day cell of the Calendar
    *
    * @param string $color HTML color
    */
    function setFullDayBGColor($color) {
        $this->fd_bgcolor = $color;
    }

    /**
    * Sets the cell box size of the Calendar
    * Min size = 20
    * Max size = 80
    *
    * @param int $size box size (in pixels)
    */
    function setBoxSize($size) {
        $size = intval($size);
        if ($size < 20)
            $size = 20;
        if ($size > 80)
            $size = 80;
        $this->boxSize = $size . 'px';
    }

    /**
    * Sets the color of the day links of the Calendar
    *
    * @param string $color HTML color
    */
    function setLinkColor($color) {
        $this->linkColor = $color;
    }

    /**
    * Sets the hover color of day links of the Calendar
    *
    * @param string $color HTML color
    */
    function setLinkHover($color) {
        $this->linkHover = $color;
    }

    /**
    * Sets the color month links of the Calendar
    *
    * @param string $color HTML color
    */
    function setMonthColor($color) {
        $this->monthColor = $color;
    }

    /**
    * Sets the hover color month links of the Calendar
    *
    * @param string $color HTML color
    */
    function setMonthHover($color) {
        $this->monthHover = $color;
    }

    /**
    * Sets the background color the month select of the Calendar
    *
    * @param string $color HTML color
    */
    function setSelectBGColor($color) {
        $this->select_bgcolor = $color;
    }

    /**
    * Sets the background color the month select of the Calendar
    *
    * @param int $size font size (in pixels)
    */
    function setSelectSize($size) {
        $this->selectSize = $size . 'px';
    }

    /**
    * Sets the text color the month select of the Calendar
    *
    * @param string $color HTML color
    */
    function setSelectTextColor($color) {
        $this->select_textcolor = $color;
    }

    /**
    * Sets the common font size of the Calendar
    *
    * @param int $size font size (in pixels)
    */
    function setTextSize($size) {
        $this->textSize = intval($size) . 'px';
    }
}
?>